@@ -721,6 +721,12 @@ def _unittest_parse_namespace() -> None:
     assert 'zubax.Message' in [x.full_name for x in parsed]
     assert 'zubax.nested.Spartans' in [x.full_name for x in parsed]
 
+    # try again with minimal arguments to read_namespace
+    parsed_minmal_args = _namespace.read_namespace(
+        os.path.join(directory.name, 'zubax')
+    )
+    assert len(parsed_minmal_args) == 3
+
     _define(
         'zubax/colliding/300.Iceberg.30.0.uavcan',
         dedent("""
@@ -735,8 +741,11 @@ def _unittest_parse_namespace() -> None:
             print_handler
         )
 
-    with raises(TypeError):  # Invalid usage: expected a list of paths, not a single path.
-        _namespace.read_namespace(os.path.join(directory.name, 'zubax'), '/my/path')
+    with raises(TypeError):  # Invalid usage: expected path-like object, not bytes.
+        _namespace.read_namespace(os.path.join(directory.name, 'zubax'), b'/my/path')  # type: ignore
+
+    with raises(TypeError):  # Invalid usage: expected path-like object, not bytes.
+        _namespace.read_namespace(os.path.join(directory.name, 'zubax'), [b'/my/path'])  # type: ignore
 
     assert print_output is not None
     assert '300.Spartans' in print_output[0]
@@ -754,6 +763,11 @@ def _unittest_parse_namespace() -> None:
             os.path.join(directory.name, 'zubax'),
         ])
 
+    # Do again to test single lookup-directory override
+    with raises(_namespace.DataTypeNameCollisionError):
+        _namespace.read_namespace(os.path.join(directory.name, 'zubax'),
+                                  os.path.join(directory.name, 'zubax'))
+
     try:
         os.unlink(os.path.join(directory.name, 'zubax/colliding/iceberg/300.Ice.30.0.uavcan'))
         _define(
